##  Notifications of Configuration Changes
Whenever significant changes are made to the meta model configuration by an admin, an email notification is sent to all workspace admins, including the user who made the changes. This is important for audit trails and maintaining transparency across all administrative actions.
YesNo
Send
